/*
    File created Thursday, August 18, 2005 at 19:28
    Example of how to use the GetElasticity-function and estimate
    multiple models within a single object.
    Data : Greene.xls
*/
#include <oxstd.h>
#include "dcm.ox"        // Include DCM package
main()
{
    decl dcm = new DCM();                       // Create a DCM object
    dcm.Load("Greene.xls");                     // Load database
    dcm.Deterministic(TRUE);                    // Append alt. spec. constants
    dcm.SetAltNames({"air","train","bus","car"}); // Set new alt. names
    dcm.SetRefAlt("car");                       // Set reference alternative
    dcm.Select(Y_VAR,{"Mode",0,0});             // Select dependent variable
    dcm.Select(A_VAR,{"GC",0,0,"Ttme",0,0});    // Select independent variables
    dcm.Interact({"air"},{"Hinc"});             // Append and select interactions
    dcm.SetAlgorithm(BFGS);

    // Model 1: CL
    dcm.SetModel(CL);
    dcm.Estimate();     
    
    decl cl;
   
    dcm.GetElasticity("GC",1,&cl);
    
    cl[0].Print(); println("\nTable print-out suitable for screen:");
	
    cl[0].LaTeX(); println("\nTable print-out suitable for LaTeX-documents:");
    
    cl[0].Text(); println("\nTable print-out suitable for conversion to MS Word or Excel:");
   
    println(cl[0].GetContents()[0]);		      //prints unformatted elasticities
    println(cl[0].GetContents()[1]);              //prints unformatted marginal effects
											
    // Model 2: NL (Note that we do not need to respecify the model specifications)
    dcm.SetModel(NL);
    dcm.SetNest({0,<1,2,3>}); 
    dcm.Estimate();
    decl nl;
    dcm.GetElasticity("GC",1,&nl);    

    // Model 3: Analog Nested Logit
    dcm.SetModel(MXL);
    // Create dummies for Fly={air} and Grnd={train,bus,car}
    dcm.Append(ones(210,1)**<1;0;0;0>,"Fly");
    dcm.Append(ones(210,1)**<0;1;1;1>,"Grnd");              
    dcm.Select(A_VAR,{"Fly",0,0,"Grnd",0,0});
    dcm.SetCoeffDist(NORMAL,{"Fly"});
    dcm.InitData();
    dcm.InitPar();
    dcm.FixPar(<5;6>,0);  // NB: We need to fix the mean coeff's of Fly and Grnd as we also include ASC.
    dcm.Estimate();
    decl anl;
    dcm.GetElasticity("GC",1,&anl);
    

    // Create a table where we present the elasticities for all three models.
    decl tb = new Table();          
        tb.Title("Table of Elasticities: Different Model Specifications");
        tb.Header(dcm.GetAltNames()); // column headers
        tb.Label(dcm.GetAltNames()); // row labels
        tb.SubLabel({"CL","NL","ANL"});
        tb.Add(cl[0].GetContents()[0]);      // Get CL-elasticities
        tb.Add(nl[0].GetContents()[0]);     // Get NL-elasticities
        tb.Add(anl[0].GetContents()[0]);   // Get ANL-elasticities
        tb.Print();    
    delete tb;
}
